@@ -11,7 +11,7 @@ class Test_Cache_Apc extends Test_Cache_Test
     if (ini_get("apc.enable_cli") === "1") {
       return self::createSuite("Test_Cache_Apc");
     } else {
-      throw new Exception("must enable 'apc.enable_cli' in your php.ini");
+      return self::createSuite("");
     }
   }
   
