@@ -11,14 +11,9 @@
  */
 class Sabel_DB_Mysqli_Statement extends Sabel_DB_Mysql_Statement
 {
-  public function setDriver($driver)
+  public function __construct(Sabel_DB_Mysqli_Driver $driver)
   {
-    if ($driver instanceof Sabel_DB_Mysqli_Driver) {
-      $this->driver = $driver;
-    } else {
-      $message = "driver should be an instance of Sabel_DB_Mysqli_Driver";
-      throw new Sabel_Exception_InvalidArgument($message);
-    }
+    $this->driver = $driver;
   }
   
   public function escape(array $values)
@@ -35,15 +30,4 @@ class Sabel_DB_Mysqli_Statement extends Sabel_DB_Mysql_Statement
     
     return $values;
   }
-  
-  public function escapeBinary($string)
-  {
-    $conn = $this->driver->getConnection();
-    return "'" . mysqli_real_escape_string($conn, $string) . "'";
-  }
-  
-  public function unescapeBinary($byte)
-  {
-    return $byte;
-  }
 }
